boofun.utils.exceptions
=========================

.. automodule:: boofun.utils.exceptions

   .. rubric:: Error Codes

   .. autosummary::
      :toctree: generated/

      ErrorCode

   .. rubric:: Base Exception

   .. autosummary::
      :toctree: generated/

      BooleanFunctionError

   .. rubric:: Validation Errors (E1xxx)

   .. autosummary::
      :toctree: generated/

      ValidationError
      InvalidInputError
      InvalidRepresentationError
      InvalidTruthTableError

   .. rubric:: Evaluation Errors (E2xxx)

   .. autosummary::
      :toctree: generated/

      EvaluationError

   .. rubric:: Conversion Errors (E3xxx)

   .. autosummary::
      :toctree: generated/

      ConversionError

   .. rubric:: Configuration Errors (E4xxx)

   .. autosummary::
      :toctree: generated/

      ConfigurationError

   .. rubric:: Resource Errors (E5xxx)

   .. autosummary::
      :toctree: generated/

      ResourceUnavailableError

   .. rubric:: Internal Errors (E9xxx)

   .. autosummary::
      :toctree: generated/

      InvariantViolationError
